@@ -48,9 +48,10 @@ class CHGraph(object):
             """
             创建子图的计算属性表
             """
-            _type, info = self.graph_cfg.get("vertexes", {}).items()[0]
-            self.create_subgraph_ext_table("vertexes", subgraph_name, info, cluster_config.is_cluster,
+            for _type, info in self.graph_cfg.get("vertexes", {}).items():
+                self.create_subgraph_ext_table("vertexes", subgraph_name, info, cluster_config.is_cluster,
                                            cluster_config.cluster_name)
+                return
         except Exception as e:
             logger.error("create ext subgraph error. errMsg:{}".format(str(e)))
             return "create ext table filed !!"
@@ -1320,7 +1321,7 @@ class CHGraph(object):
         columns_str = "(\n    `id` String,\n   " \
                       " `task_id` String,\n    " \
                       " `id_type` String,\n    " \
-                      "`graph_algorithm_type` String,\n   " \
+                      "`graph_algorithm_type` Float64,\n   " \
                       " `val` String,\n    " \
                       "`create_time` DateTime64(3) DEFAULT now() CODEC(DoubleDelta, LZ4)\n)\n"
         engine_str = "ENGINE = MergeTree"
@@ -1343,7 +1344,7 @@ class CHGraph(object):
                       " id_type String,\n    " \
                       " task_id String,\n    " \
                       " graph_algorithm_type String,\n   " \
-                      " val String,\n    " \
+                      " val Float64,\n    " \
                       " create_time DateTime64(3) DEFAULT now() CODEC(DoubleDelta, LZ4)\n)\n"
             handler = SqlMergeHandler(graph_type, subgraph_name, edge_or_vertex_info, cluster_name)
             # 创建本地表
